==> weixin-java-mp-1.3.5-sources.jar: me/chanjar/weixin/mp/bean/result/WxMpPrepayIdResult.java <==
package me.chanjar.weixin.mp.bean.result;

import java.io.Serializable;

/**
 * <pre>
 * 在发起微信支付前，需要调用统一下单接口，获取"预支付交易会话标识"返回的结果
 *
 * 统一下单(详见http://pay.weixin.qq.com/wiki/doc/api/jsapi.php?chapter=9_1)
 *
 * </pre>
 *
 * @author chanjarster
 */
public class WxMpPrepayIdResult implements Serializable {
    private String return_code;
    private String return_msg;
    private String appid;
    private String mch_id;
    private String nonce_str;
    private String sign;
    private String result_code;
    private String prepay_id;
    private String trade_type;
    private String err_code;
    private String err_code_des;
    private String code_url;

    public String getReturn_code() {
        return return_code;
    }

    public void setReturn_code(String return_code) {
        this.return_code = return_code;
    }

    public String getReturn_msg() {
        return return_msg;
    }

    public void setReturn_msg(String return_msg) {
        this.return_msg = return_msg;
    }

    public String getAppid() {
        return appid;
    }

    public void setAppid(String appid) {
        this.appid = appid;
    }

    public String getMch_id() {
        return mch_id;
    }

    public void setMch_id(String mch_id) {
        this.mch_id = mch_id;
    }

    public String getNonce_str() {
        return nonce_str;
    }

    public void setNonce_str(String nonce_str) {
        this.nonce_str = nonce_str;
    }

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public String getResult_code() {
        return result_code;
    }

    public void setResult_code(String result_code) {
        this.result_code = result_code;
    }

    public String getPrepay_id() {
        return prepay_id;
    }

    public void setPrepay_id(String prepay_id) {
        this.prepay_id = prepay_id;
    }

    public String getTrade_type() {
        return trade_type;
    }

    public void setTrade_type(String trade_type) {
        this.trade_type = trade_type;
    }
    
    public String getErr_code() {
      return err_code;
    }

    public void setErr_code(String err_code) {
      this.err_code = err_code;
    }

    public String getErr_code_des() {
      return err_code_des;
    }

    public void setErr_code_des(String err_code_des) {
      this.err_code_des = err_code_des;
    }

    public String getCode_url() {
      return code_url;
    }

    public void setCode_url(String code_url) {
      this.code_url = code_url;
    }
}

==> weixin-java-mp-2.1.0-sources.jar: me/chanjar/weixin/mp/bean/result/WxMpPrepayIdResult.java <==
package me.chanjar.weixin.mp.bean.result;

import java.io.Serializable;

/**
 * <pre>
 * 在发起微信支付前，需要调用统一下单接口，获取"预支付交易会话标识"返回的结果
 *
 * 统一下单(详见http://pay.weixin.qq.com/wiki/doc/api/jsapi.php?chapter=9_1)
 *
 * </pre>
 *
 * @author chanjarster
 */
public class WxMpPrepayIdResult implements Serializable {
    /**
   * 
   */
  private static final long serialVersionUID = -8970574397788396143L;
    private String return_code;
    private String return_msg;
    private String appid;
    private String mch_id;
    private String nonce_str;
    private String sign;
    private String result_code;
    private String prepay_id;
    private String trade_type;
    private String err_code;
    private String err_code_des;
    private String code_url;

    public String getReturn_code() {
        return this.return_code;
    }

    public void setReturn_code(String return_code) {
        this.return_code = return_code;
    }

    public String getReturn_msg() {
        return this.return_msg;
    }

    public void setReturn_msg(String return_msg) {
        this.return_msg = return_msg;
    }

    public String getAppid() {
        return this.appid;
    }

    public void setAppid(String appid) {
        this.appid = appid;
    }

    public String getMch_id() {
        return this.mch_id;
    }

    public void setMch_id(String mch_id) {
        this.mch_id = mch_id;
    }

    public String getNonce_str() {
        return this.nonce_str;
    }

    public void setNonce_str(String nonce_str) {
        this.nonce_str = nonce_str;
    }

    public String getSign() {
        return this.sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public String getResult_code() {
        return this.result_code;
    }

    public void setResult_code(String result_code) {
        this.result_code = result_code;
    }

    public String getPrepay_id() {
        return this.prepay_id;
    }

    public void setPrepay_id(String prepay_id) {
        this.prepay_id = prepay_id;
    }

    public String getTrade_type() {
        return this.trade_type;
    }

    public void setTrade_type(String trade_type) {
        this.trade_type = trade_type;
    }
    
    public String getErr_code() {
      return this.err_code;
    }

    public void setErr_code(String err_code) {
      this.err_code = err_code;
    }

    public String getErr_code_des() {
      return this.err_code_des;
    }

    public void setErr_code_des(String err_code_des) {
      this.err_code_des = err_code_des;
    }

    public String getCode_url() {
      return this.code_url;
    }

    public void setCode_url(String code_url) {
      this.code_url = code_url;
    }
}
